@@ -30,7 +30,7 @@ def test_sendemail(mock_app, mock_mail):
 
     runner = mock_app.test_cli_runner()
     # When invoking the test email command with a recipient paramrter
-    result = runner.invoke(cli, ["test", "email", "--recipient", "test_user@mail.com"])
+    runner.invoke(cli, ["test", "email", "--recipient", "test_user@mail.com"])
 
     # Make sure that mock mail send method was called and mock email is sent
     assert mock_mail._send_was_called
